Learn R Programming

weatherOz (version 3.0.1)

find_forecast_towns: Find the Nearest Town With a BOM Forecast

Description

For a given latitude and longitude, find the nearest town that the BOM provides a forecast for.

Usage

find_forecast_towns(longitude = 149.2, latitude = -35.3, distance_km = 100)

Value

A data.table::data.table() of all forecast towns (in this package) sorted by distance from latitude and longitude, ascending.

Arguments

longitude

A numeric value of longitude in decimal degree (DD) format. By default, Canberra (approximately).

latitude

A numeric value of latitude in decimal degree (DD) format. By default, Canberra (approximately).

distance_km

A numeric value of the distance in kilometres from the latitude and longitude point beyond which values will not be returned.

Author

Hugh Parsonage, [email protected], and James Goldie, [email protected], and Adam H. Sparks, [email protected]

See Also

Other BOM: get_available_imagery(), get_available_radar(), get_coastal_forecast(), get_precis_forecast(), get_radar_imagery(), get_satellite_imagery(), parse_coastal_forecast(), parse_precis_forecast()

Other metadata: find_nearby_stations(), find_stations_in(), get_available_imagery(), get_available_radar(), get_dpird_availability(), get_stations_metadata()

Examples

Run this code
if (FALSE) { # interactive()

# find forecast towns near Esperance, WA
find_forecast_towns(longitude = 121.8913, latitude = -33.8614)
}

Run the code above in your browser using DataLab