View source: R/get_dpird_apsim.R
| get_dpird_apsim | R Documentation |
Automates the retrieval and conversion of summary data from the DPIRD Weather 2.0 API to an APSIM .met file formatted weather data object.
get_dpird_apsim(
station_code,
start_date,
end_date = Sys.Date(),
api_key = get_key(service = "DPIRD")
)
station_code |
A |
start_date |
A |
end_date |
A |
api_key |
A |
An apsimx object of class ‘met’ with attributes.
To save “met” objects the apsimx::write_apsim_met() is reexported.
Note that when saving, comments from SILO will be included, but these will
not be printed as a part of the resulting met object in your R session.
Adam H. Sparks, adamhsparks@gmail.com
Other DPIRD:
dpird_extreme_weather_values,
dpird_minute_values,
dpird_summary_values,
find_nearby_stations(),
find_stations_in(),
get_dpird_availability(),
get_dpird_extremes(),
get_dpird_minute(),
get_dpird_summaries(),
get_stations_metadata()
Other data fetching:
get_ag_bulletin(),
get_coastal_forecast(),
get_data_drill(),
get_data_drill_apsim(),
get_dpird_extremes(),
get_dpird_minute(),
get_dpird_summaries(),
get_patched_point(),
get_patched_point_apsim(),
get_precis_forecast(),
get_radar_imagery(),
get_satellite_imagery()
Other APSIM:
get_data_drill_apsim(),
get_patched_point_apsim(),
reexports
## Not run:
# Get an APSIM format object for Binnu
# Note that you need to supply your own API key
wd <- get_dpird_apsim(
station_code = "BI",
start_date = "20220101",
end_date = "20221231",
api_key = "your_api_key"
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.