powered by
For a given latitude and longitude, find the nearest town that the BOM provides a forecast for.
latitude
longitude
find_forecast_towns(longitude = 149.2, latitude = -35.3, distance_km = 100)
A data.table::data.table() of all forecast towns (in this package) sorted by distance from latitude and longitude, ascending.
data.table::data.table()
A numeric value of longitude in decimal degree (DD) format. By default, Canberra (approximately).
numeric
A numeric value of latitude in decimal degree (DD) format. By default, Canberra (approximately).
A numeric value of the distance in kilometres from the latitude and longitude point beyond which values will not be returned.
Hugh Parsonage, [email protected], and James Goldie, [email protected], and Adam H. Sparks, [email protected]
Other BOM: get_available_imagery(), get_available_radar(), get_coastal_forecast(), get_precis_forecast(), get_radar_imagery(), get_satellite_imagery(), parse_coastal_forecast(), parse_precis_forecast()
get_available_imagery()
get_available_radar()
get_coastal_forecast()
get_precis_forecast()
get_radar_imagery()
get_satellite_imagery()
parse_coastal_forecast()
parse_precis_forecast()
Other metadata: find_nearby_stations(), find_stations_in(), get_available_imagery(), get_available_radar(), get_dpird_availability(), get_stations_metadata()
find_nearby_stations()
find_stations_in()
get_dpird_availability()
get_stations_metadata()
if (FALSE) { # interactive() # find forecast towns near Esperance, WA find_forecast_towns(longitude = 121.8913, latitude = -33.8614) }
Run the code above in your browser using DataLab